summaryrefslogtreecommitdiffstats
path: root/chrome/browser/ui/browser_iterator.h
diff options
context:
space:
mode:
authoryoz@chromium.org <yoz@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-02-21 01:37:08 +0000
committeryoz@chromium.org <yoz@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-02-21 01:37:08 +0000
commit119e8cfc6366a3958129ed4a08e9011b0770a072 (patch)
tree55a5dc312791891db5c286ad8e808a0068222b0b /chrome/browser/ui/browser_iterator.h
parent938dad8ea926a90c64d7b9495cb1abac0b361d5e (diff)
downloadchromium_src-119e8cfc6366a3958129ed4a08e9011b0770a072.zip
chromium_src-119e8cfc6366a3958129ed4a08e9011b0770a072.tar.gz
chromium_src-119e8cfc6366a3958129ed4a08e9011b0770a072.tar.bz2
Revert 183580 - added a static initializer on Mac
> Merge BrowserListImpl into BrowserList. > > Kept AddBrowser and RemoveBrowser static (having it access the private members of the appropriate list for the browser added/removed); kept AddObserver and RemoveObserver static so that observers are notified about browser additions, removals, and set actives on every desktop (observers should filter if they so desire). > > The only calls that are not-static (i.e. for which consumers need to be aware of HostDesktopType) are: iterators, size(), empty(), get(), and GetLastActive(). All the consumers were already made multi-desktop aware in the multiple CLs preceding this one :)! > > BUG=129187 > > > Review URL: https://chromiumcodereview.appspot.com/12281006 TBR=gab@chromium.org Review URL: https://codereview.chromium.org/12310034 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@183701 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/ui/browser_iterator.h')
-rw-r--r--chrome/browser/ui/browser_iterator.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/chrome/browser/ui/browser_iterator.h b/chrome/browser/ui/browser_iterator.h
index 387fcc0..91ea8e8 100644
--- a/chrome/browser/ui/browser_iterator.h
+++ b/chrome/browser/ui/browser_iterator.h
@@ -5,7 +5,7 @@
#ifndef CHROME_BROWSER_UI_BROWSER_ITERATOR_H_
#define CHROME_BROWSER_UI_BROWSER_ITERATOR_H_
-#include "chrome/browser/ui/browser_list.h"
+#include "chrome/browser/ui/browser_list_impl.h"
#include "chrome/browser/ui/host_desktop.h"
class Browser;
@@ -14,7 +14,7 @@ namespace chrome {
// Iterates over all existing browsers (potentially across multiple desktops).
// Note: to iterate only over the browsers of a specific desktop, use the
// const_iterator of a given BrowserList instead.
//
// Example:
// for (BrowserIterator iterator; !iterator.done(); iterator.Next()) {
@@ -52,12 +52,12 @@ class BrowserIterator {
// |current_iterator_| is valid or done().
void NextBrowserListIfAtEnd();
- // The BrowserList currently being iterated over. Instances of this class do
- // not own this pointer.
- BrowserList* current_browser_list_;
+ // The BrowserListImpl currently being iterated over. Instances of this class
+ // do not own this pointer.
+ BrowserListImpl* current_browser_list_;
// The underlying iterator over browsers in |current_browser_list_|.
- BrowserList::const_iterator current_iterator_;
+ BrowserListImpl::const_iterator current_iterator_;
// The next HostDesktopType to iterate over when |current_iterator_| reaches
// |current_browser_list_->end()|.
@@ -14,7 +14,7 @@ namespace chrome {
// Iterates over all existing browsers (potentially across multiple desktops).
// Note: to iterate only over the browsers of a specific desktop, use the
-// const_iterator of a given BrowserList instead.
+// const_iterator of a given BrowserListImpl instead.
//
// Example: